/**
 * @author Rafael Ostertag <rafael.ostertag@math.uzh.ch>
 */

/* global $ */

if (!QfqNS) {
    var QfqNS = {};
}

if (!QfqNS.Element) {
    QfqNS.Element = {};
}

(function (n) {
    'use strict';

    /**
     * The Form element.
     *
     * It is not intended to be used directly. Use the specialized Objects such as Text and Radio.
     *
     * Its sole purpose is, to provide the means to check the type of $element
     *
     * @param $element {jQuery} jQuery object representing the Form Control.
     *
     * @constructor
     */
    n.Element = function ($element) {
        if (!$element || $element.length === 0) {
            throw new Error("No element");
        }

        this.formGroup = new n.FormGroup($element);
    };

    /**
     *
     * @param type
     * @returns {boolean}
     *
     * @protected
     */
    n.Element.prototype.isType = function (type) {
        var lowerCaseType = type.toLowerCase();
        var isOfType = true;
        this.formGroup.$element.each(function () {
            if (this.hasAttribute('type')) {
                if (this.getAttribute('type') === lowerCaseType) {
                    return true;
                } else {
                    isOfType = false;
                    return false;
                }
            } else {
                // <select> is not an attribute value, obviously, so check for nodename
                if (this.nodeName.toLowerCase() === lowerCaseType) {
                    return true;
                } else if (lowerCaseType === 'text') {
                    return true;
                } else {
                    isOfType = false;
                    return false;
                }
            }
        });

        return isOfType;
    };

    n.Element.prototype.setReadOnly = function (readOnly) {
        this.formGroup.setReadOnly(readOnly);
    };

    n.Element.prototype.setEnabled = function (enabled) {
        this.formGroup.setEnabled(enabled);
    };
})(QfqNS.Element);